from setuptools import find_packages, setup

setup(
    name='studiopulsee',
    version='0.17.1',  # Set your version here
    description='It\'s a Python library for VFX project-based LAN deployment',
    author='Hitech Enterprise',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
                'aiohttp==3.9.5',
                'aiosignal==1.3.1',
                'alembic==1.13.2',
                'aniso8601==9.0.1',
                'annotated-types==0.7.0',
                'async-timeout==4.0.3',
                'attrs==23.2.0',
                'Babel==2.13.1',
                'bcrypt==4.1.3',
                'bidict==0.23.1',
                'blinker==1.8.2',
                'boto3==1.34.135',
                'botocore==1.34.135',
                'cachelib==0.9.0',
                'camel-converter==3.1.2',
                'certifi==2024.6.2',
                'cffi==1.16.0',
                'charset-normalizer==3.3.2',
                'click==8.1.7',
                'cryptography==42.0.8',
                'debtcollector==3.0.0',
                'discord.py==2.3.2',
                'dnspython==2.6.1',
                'email-validator==2.1.0.post1',
                'ffmpeg-python==0.2.0',
                'fido2==1.1.2',
                'flasgger==0.9.7.1',
                'Flask==3.0.0',
                'Flask-Bcrypt==1.0.1',
                'Flask-Caching==2.1.0',
                'Flask-Fixtures==0.3.8',
                'flask-fs2==0.7.23',
                'Flask-JWT-Extended==4.5.3',
                'Flask-Mail==0.9.1',
                'Flask-Migrate==4.0.5',
                'Flask-Principal==0.4.0',
                'Flask-RESTful==0.3.10',
                'Flask-SocketIO==5.3.6',
                'Flask-SQLAlchemy==3.1.1',
                'frozenlist==1.4.1',
                'future==1.0.0',
                'gazu==0.9.14',
                'gevent==23.9.1',
                'gevent-websocket==0.10.1',
                'greenlet==3.0.3',
                'gunicorn==21.2.0',
                'h11==0.14.0',
                'idna==3.7',
                'iso8601==2.1.0',
                'isoweek==1.3.3',
                'itsdangerous==2.1.2',
                'Jinja2==3.1.2',
                'jmespath==1.0.1',
                'jsonschema==4.22.0',
                'jsonschema-specifications==2023.12.1',
                'keystoneauth1==5.6.0',
                'ldap3==2.9.1',
                'Mako==1.3.5',
                'MarkupSafe==2.1.5',
                'matterhook==0.2',
                'meilisearch==0.28.4',
                'mistune==3.0.2',
                'msgpack==1.0.8',
                'multidict==6.0.5',
                'netaddr==1.3.0',
                'netifaces==0.11.0',
                'numpy==1.24.4',
                'opencv-python==4.8.1.78',
                'OpenTimelineIO==0.15.0',
                'orjson==3.9.10',
                'os-service-types==1.7.0',
                'oslo.config==9.4.0',
                'oslo.i18n==6.3.0',
                'oslo.serialization==5.4.0',
                'oslo.utils==7.1.0',
                'packaging==24.1',
                'pbr==6.0.0',
                'Pillow==10.1.0',
                'psutil==5.9.6',
                'psycopg==3.1.12',
                'psycopg-binary==3.1.12',
                'pyaaf2==1.6.0',
                'pyasn1==0.6.0',
                'pycparser==2.22',
                'pydantic==2.7.4',
                'pydantic_core==2.18.4',
                'PyJWT==2.8.0',
                'pyotp==2.9.0',
                'pyparsing==3.1.2',
                'python-dateutil==2.8.2',
                'python-engineio==4.9.1',
                'python-keystoneclient==5.4.0',
                'python-nomad==2.0.0',
                'python-slugify==8.0.1',
                'python-socketio==5.10.0',
                'python-swiftclient==4.6.0',
                'pytz==2023.3.post1',
                'PyYAML==6.0.1',
                'redis==5.0.1',
                'referencing==0.35.1',
                'requests==2.31.0',
                'rfc3986==2.0.0',
                'rpds-py==0.18.1',
                'rq==1.15.1',
                's3transfer==0.10.2',
                'simple-websocket==1.0.0',
                'six==1.16.0',
                'slackclient==2.9.4',
                'SQLAlchemy==2.0.23',
                'SQLAlchemy-Utils==0.41.1',
                'stevedore==5.2.0',
                'text-unidecode==1.3',
                'typing_extensions==4.12.2',
                'tzdata==2024.1',
                'ua-parser==0.18.0',
                'urllib3==2.2.2',
                'websocket-client==1.8.0',
                'Werkzeug==3.0.1',
    ],
    
    entry_points={
        'console_scripts': [
            'studiopulsee=studiopulsee.app:main',  # Adjust this to your main function
        ],
    },
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    test_suite='tests',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Flask',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Multimedia :: Graphics',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
